@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ SelectMultiCollectionWidget::~SelectMultiCollectionWidget()
 void SelectMultiCollectionWidget::initialize(const QString &mimetype)
 {
     QVBoxLayout *vbox = new QVBoxLayout(this);
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
 
     mCheckedCollectionWidget = new PimCommon::CheckedCollectionWidget(mimetype);
 
